@@ -1,5 +1,5 @@
 /* GENIUS Calculator
- * Copyright (C) 2004-2005 George Lebl
+ * Copyright (C) 2004-2009 George Lebl
  *
  * Author: George Lebl
  *
@@ -29,12 +29,12 @@ typedef struct {
 	int scrollback;
 	char *font;
 	gboolean black_on_white;
+	gboolean output_remember; /* remember output settings */
+	gboolean precision_remember; /* remember precision setting */
 } GeniusSetup;
 
 extern GeniusSetup genius_setup;
 extern GtkWidget *genius_window;
-extern GHashTable *uncompiled;
-extern calcstate_t calcstate;
 
 void genius_interrupt_calc (void);
 
@@ -44,4 +44,9 @@ void genius_unsetup_window_cursor (GtkWidget *win);
 gboolean genius_ask_question (GtkWidget *parent, const char *question);
 void genius_display_error (GtkWidget *parent, const char *err);
 
+/* same as GNOME */
+#define GENIUS_PAD          8
+#define GENIUS_PAD_SMALL    4
+#define GENIUS_PAD_BIG      12
+
 #endif /* GNOME_GENIUS_H_ */
